@@ -7,54 +7,11 @@ pub mod mutvec;
 pub mod vecvecf64;
 pub mod functions;
 
+// reexporting to avoid duplication and for backwards compatibility
+pub use indxvec::{here,wi}; 
 /// simple error handling
 use anyhow::{Result,bail}; 
 
-/// macro here!() gives &str with the current file:line path::function for error messages
-#[macro_export]
-macro_rules! here {
-    () => {{
-        fn f() {}
-        fn type_name_of<T>(_: T) -> &'static str {
-            std::any::type_name::<T>()
-        }
-        let name = type_name_of(f);
-        // For function name only:
-        // let fnct = match &name[..name.len()-3].rfind(':') {
-        //    Some(pos) => &name[pos + 1..name.len() - 3],
-        //    None => &name[..name.len()-3],
-        // };
-        format!("\n{}:{} {}", file!(), line!(), &name[..name.len()-3])
-    }}
-}
-
-/// GreenIt (GI) struct facilitates printing (in green) any
-/// singular type that has Display implemented.
-pub struct GI<T: std::fmt::Display>(pub T);
-impl<T: std::fmt::Display> std::fmt::Display for GI<T> {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        write!(f, "\x1B[01;92m{}\x1B[0m", self.0.to_string())
-    }
-}
-
-/// GreenVec (GV) wrapper struct facilitates printing (in green) vector
-/// of any end type that has Display implemented.
-pub struct GV<'a, T: std::fmt::Display>(pub &'a[T]);
-impl<'a, T: std::fmt::Display> std::fmt::Display for GV<'a,T> {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        let mut s = String::from("\x1B[01;92m[");
-        let n = self.0.len();
-        if n > 0 {
-            s.push_str(&self.0[0].to_string()); // first item
-            for i in 1..n {
-                s.push_str(", ");
-                s.push_str(&self.0[i].to_string());
-            }
-        }
-        write!(f, "{}]\x1B[0m", s)
-    }
-}
-
 /// Median and quartiles
 #[derive(Default)]
 pub struct Med {
@@ -67,9 +24,9 @@ impl std::fmt::Display for Med {
         write!(
             f,
             "median:\n\tLower Q: {}\n\tMedian:  {}\n\tUpper Q: {}",
-            GI(self.lquartile),
-            GI(self.median),
-            GI(self.uquartile)
+            wi(&self.lquartile),
+            wi(&self.median),
+            wi(&self.uquartile)
         )
     }
 }
@@ -82,7 +39,7 @@ pub struct MStats {
 }
 impl std::fmt::Display for MStats {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        write!(f, "mean±std: {}±{}", GI(self.mean), GI(self.std))
+        write!(f, "mean±std: {}±{}", wi(&self.mean), wi(&self.std))
     }
 }
 
@@ -123,14 +80,6 @@ pub trait Stats {
     /// Median and quartiles
     fn median(self) -> Result<Med>
         where Self: std::marker::Sized { bail!("median not implemented for this type")}
-/*        
-    /// Creates vector of ranks for values in self
-    fn ranks(self) -> Result<Vec<f64>>
-        where Self: std::marker::Sized { bail!("ranks not implemented for this type")}
-    /// Creates vector of integer ranks for values in self
-    fn iranks(self) -> Result<Vec<i64>>
-        where Self: std::marker::Sized { bail!("iranks not implemented for this type")}    
-*/
 }
 
 /// Vector algebra on one or two vectors.
@@ -185,9 +134,6 @@ pub trait Vecf64 {
     fn covone(self, m:&[f64]) -> Vec<f64>;
     /// Reconstructs the full symmetric matrix from its lower diagonal compact form
     fn symmatrix(self) -> Vec<Vec<f64>>;
- 
-    // Minimum, minimum's index, maximum, maximum's index.
-    // fn minmax(self) -> (f64, usize, f64, usize); 
     /// Linear transformation to [0,1]
     fn lintrans(self) -> Vec<f64>;
     // Sort vector in a standard way
